import React, { useEffect, useMemo, useRef, useState } from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import usePrevious from '@/utils/hooks/usePrevious';
import Column from './Column';
import { useColumn, useRenderFunc } from './hooks';
import { classNames, getRect } from './utils';

import './style.less'

/**
 * 核心原理, 左右2栏，一个个放元素，同时记录高度，优先放入低高度区域
 * 元素高度获取，主要是通过图片的 onLoad 来确保加载完成
 * 
 * 复杂度, 多数据公用 list,
 * 需要区分是否更换数据源，是否未更换数据源，只是新增了数据
 */

export default (props) => {
  const { className, listData, render } = props

  // rfTimes 用来区分是否更换数据源
  const { list, rfTimes: refresh } = listData

  // 用来绘制页面的数据
  // const renderListRef = useRef([])

  const lastList = usePrevious(list)
  // const lastRf = usePrevious(refresh)


  // 记录左右2栏的数据及高度
  // const leftHeight = useRef(0)
  // const rightHeight = useRef(0)
  // const [leftList, appendLeft, setLeftList] = useColumn()
  // const [rightList, appendRight, setRightList] = useColumn()
  const [leftList, setLeftList] = useState([])
  const [rightList, setRightList] = useState([])
  
  // 渲染逻辑
  // const forceRender = useRenderFunc(renderListRef, leftHeight, rightHeight, appendLeft, appendRight)

  // 每个元素渲染完成, 会拿到当前栏的高度
  const handleRenderFinish = (direct) => (height) => {
    // if (direct === 'left') {
    //   leftHeight.current = height
    // } else {
    //   rightHeight.current = height
    // }

    // //
    // forceRender.current()
  }
  
  // console.debug('------leftHeight------->', leftHeight.current)
  // console.debug('------rightHeight------->', rightHeight.current)
  // console.debug('------renderListRef------->', renderListRef.current)
  // console.debug('------list------->', list)

  useEffect(() => {
    if (lastList && lastList === list) return;

    // // 新数据源 = 首次进入 或者 切换数据源
    // const isNew = (!lastList?.length && list.length) || (lastRf !== refresh)

    // if (!isNew) {
    //   // 非新数据源, list 变更那就说明是执行了上拉加载      
    //   // 于是, 只继续绘制变更的那部分
    //   renderListRef.current = list.slice(lastList.length)
    // } else {
    //   leftHeight.current = 0
    //   rightHeight.current = 0
    //   setLeftList([])
    //   setRightList([])
    //   renderListRef.current = list ? list.slice() : []
    // }

    // forceRender.current()

    const lst1 = []
    const lst2 = []
    list.map((item, index) => {
      if (index % 2 === 0) {
        lst1.push(item)
      } else {
        lst2.push(item)
      }
    })

    setLeftList(lst1)
    setRightList(lst2)
  }, [lastList, list])

  return (
    <View className={classNames(className, 'masonry-layout')}>
      <Column list={leftList} render={render} onRenderFinish={handleRenderFinish('left')} />
      <Column list={rightList} render={render} onRenderFinish={handleRenderFinish('right')} />
    </View>
  )
}
