import React, { useState, useEffect, useRef } from 'react'
import Taro, { useRouter, useShareAppMessage } from '@tarojs/taro'
import withLayout from '@/layouts'
import { getHotelManage, getNowHotelManage } from '@/services/landlord'
import NoData from '@/components/NoData'
import CustomNav from '@/components/CustomNav'
import { withSubscribeMessage } from '@/utils/subscribeMessage'
import { TPL_MESSAGE_HOTEL_CHECK_IN } from '@/utils/constants'
import { useModel } from '@/store'
import HouseManage from '../../components/HouseManage/houseManage'
import Income from '../../components/Income/income'
import tabList from './Roomtabbar'
import './landlord.less'

export default withLayout((props) => {
  const { router, person } = props
  const { params } = useRouter()
  const { tab } = params || {}

  const [hotelList, setHotelList] = useState([])
  const {hotel, setHotel} = useModel('hotel')
  const [account, setAccount] = useState({})

  const houseRef = useRef()

  useEffect(() => {
    // 禁止右上角分享
    Taro.hideShareMenu()
    getHotelManage().then((res) => {
      const { hotelList: list, account: acc, hotel: current } = res
      setHotelList(list)
      if (!hotel) {
        setHotel(current)
      }
      setAccount(acc)
    })
  }, [])

  const handleHotelChange = (current) => {
    getNowHotelManage(current.hotelId).then((res) => {
      const { account: acc } = res
      setAccount(acc)
      setHotel(current)
    })
  }

  const [currentTab, setCurrentTab] = useState(0)

  const handleTabChange = (e) => {
    const { index } = e.detail
    setCurrentTab(index)
    withSubscribeMessage([TPL_MESSAGE_HOTEL_CHECK_IN])
  }

  useEffect(() => {
    if (tab) {
      setCurrentTab(tab - 0)
    }
  }, [tab])

  useShareAppMessage(() => {
    return houseRef.current.getShareMessage()
  })

  return (
    <view className='page-index'>
      <view className='index-navbar'>
        <CustomNav title={hotel?.hotelName} logo={hotel?.logo} />
      </view>
      <view className='index-container'>
        {currentTab === 1 && <Income hotel={hotel} account={account} />}
        {hotel?.hotelId ? currentTab === 0 && <HouseManage hotelList={hotelList} hotel={hotel} onHotelChange={handleHotelChange} ref={houseRef} disabled={!hotel.hotelId} /> : <NoData />}
      </view>
      <view className='index-tabbar'>
        <mp-tabbar extClass='custom-tabbar' current={currentTab} list={tabList} onChange={handleTabChange}></mp-tabbar>
      </view>
    </view>

  )

})
