

import React, { useState, useEffect } from 'react'
import Taro, { useDidShow } from '@tarojs/taro'
import CustomNav from '@/components/CustomNav'
import logo from '@/assets/icons/comm/logo_small.png'
import { getHotelDetail } from '@/services/landlord'
import { getTaRoom } from '@/services/taRoom​'
import withLayout from '@/layouts'
import { useModel } from "@/store";
import { withSubscribeMessage } from '@/utils/subscribeMessage'
import { TPL_MESSAGE_HOTEL_CHECK_OUT } from '@/utils/constants'
import tabList from './tabbar'
import Guide from './tabs/Guide'
import Mine from './tabs/Mine'
import Recommend from './tabs/Recommend'

import './index.less'

const tips = 'https://yz-shigongli.oss-cn-shanghai.aliyuncs.com/images/sgl-v2-tips.png'

export default withLayout((props) => {
  const { router, person, location } = props
  let { roomId, roomOrderId } = router.params
  const { roomId: rid } = useModel('hotel')

  const { params, path } = router
  const { tab } = params || {}
  const [extend, setExtend] = useState([])
  //默认
  const [titleRoom, setTitleRoom] = useState('十公里')
  const [titleLogo, settitleLogo] = useState(logo)
  const { hotelId } = extend

  const [currentTab, setCurrentTab] = useState(0)

  const [isDidShow, setIsDidShow] = useState(0)

  if (!roomId && rid) {
    roomId = rid
  }

  useDidShow(() => {
    setIsDidShow(isDidShow + 1)
  })
  const handleTabChange = (e) => {
    const { index } = e.detail
    setCurrentTab(index)

    if (index === 1) {
      withSubscribeMessage([TPL_MESSAGE_HOTEL_CHECK_OUT])
    }
  }
  useEffect(() => {
    if (tab) {
      setCurrentTab(tab - 0)
    }
  }, [tab])



  useEffect(() => {
    if (roomId) {
      getTaRoom(roomId).then((res) => {
        setExtend(res)

        getHotelDetail(hotelId).then((e) => {
          setTitleRoom(e?.hotelName || '十公里')
          settitleLogo(e?.logo || logo)
        })
      })
    } else {
    }
  }, [roomId, hotelId])

  return (
    <view className='page-index'>
      <add-tips
        logo={tips}
        custom
        duration={-1} />
      <view className='index-navbar'>
        <CustomNav logo={titleLogo} title={titleRoom} />
      </view>
      <view className='index-container'>
        {currentTab === 0 && <Recommend location={location} />}
        {currentTab === 1 && <Guide person={person} router={router} location={location} />}
        {/* {currentTab === 2 && <Strategy />} */}
        {currentTab === 2 && <Mine person={person} isDidShow={isDidShow} router={router} />}
      </view>
      <view className='index-tabbar'>
        <mp-tabbar extClass='custom-tabbar' current={currentTab} list={tabList} onChange={handleTabChange}></mp-tabbar>
      </view>
    </view>
  )
})