import { useState } from "react"
import Taro from '@tarojs/taro'
import { signIn, authPhone, authAvatar, toggleRole } from '@/services/person'

export default () => {
  const [person, setPerson] = useState()
  const [qrCode, setQrCode] = useState()
  const [peronRoles, setPersonRoles] = useState([])
  const [sessionKey, setSessionKey] = useState()
  const [loading, setLoading] = useState(false)

  const login = (params) => {
    signIn(params).then((res) => {
      const { person: taPerson, personRoleList, sessionKey: skey, qrcode, token } = res;
      setPerson(taPerson);
      setPersonRoles(personRoleList);
      setQrCode(qrcode);
      setSessionKey(skey);

      Taro.setStorage({ key: 'token', data: token })
    })
  }

  const getPhone = (data) => {
    return authPhone(data).then((res) => {
      setPerson(res);
    })
  }


  const getAvatar = (data) => {
    return authAvatar(data).then((res) => {
      setPerson(res);
    })
  }

  const getRole = (data) => {
    setLoading(true)

    return toggleRole(data).then((res) => {
      setLoading(false)

      setPerson(res);
    }).catch(e => {
      setLoading(false)

    })
  }

  return {
    person,
    peronRoles,
    qrCode,
    sessionKey,
    loading,
    setPerson,
    login,
    getPhone,
    getAvatar,
    getRole
  }
}
